@@ -7,7 +7,7 @@ Yet Another Python Switch-Case
 
 from collections import defaultdict
 
-DUPS_DEFAULT = True # The default for allowing duplicate case values.
+DUPS_DEFAULT = False # The default for allowing duplicate case values.
 
 #
 # Utility classes.
@@ -17,7 +17,7 @@ _marker = "Unique element to detect error conditions."
 
 class CaseCollectingDict(dict):
     """This is a dict subclass which adds the feature of saving the data
-    passed to `__setitem__` calls for the key `_` to a dict.  It is set as the
+    passed to `__setitem__` calls for certain key values.  It is set as the
     `__prepare__` method `SwitchMetaclass`."""
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -83,7 +83,7 @@ class SwitchMetaclass(type):
         """Return the dict-like object to be set as `__dict__` (i.e., to hold
         the class attributes)."""
         dct = CaseCollectingDict() # Saves data each time a case is defined.
-        dct["_allow_dups"] = dups # Needs to be availible during class creation.
+        dct["_allow_dups"] = dups # Needs to be available during class creation.
         return dct
 
     def __init__(cls, name, bases, attrs, on=[], dups=DUPS_DEFAULT):
@@ -113,7 +113,10 @@ class Switch(metaclass=SwitchMetaclass):
             return_vals = [fundict[()][0](*args, **kwargs)]
         else:
             raise SwitchError("No case matches and no default is defined.")
-        return tuple(return_vals)
+        if cls._allow_dups:
+            return tuple(return_vals)
+        else:
+            return return_vals[0]
 
 #
 # Exceptions.
